#!/bin/bash
cd ${0%/*} || exit 1 # 他の場所からこのスクリプトを実行したときのためのもの
blockMeshDir=$PWD/../Ex2/results
resultDir=$PWD/results
workDir=$PWD/work
dictDir=$PWD/dicts
orgDir=$PWD/org_curve # ここを編集

target=wing_btm #ここで名前をつける

targetDir=$workDir/$target
mkdir -p $targetDir
cp -r $blockMeshDir/btm_bulk  $targetDir/
cp -r $blockMeshDir/top_shaft $targetDir/
cp -r $blockMeshDir/out       $targetDir/

pushd $targetDir
    cp -r btm_bulk master
    mergeMeshes master top_shaft -overwrite > $targetDir/log01.mergeMeshes
    stitchMesh -case master -overwrite wall_minz_out wall_maxz_out > $targetDir/log02.stitchMesh
    topoSet -case master -dict $dictDir/topoSetDict > $targetDir/log03.topoSet
    createBaffles -case master -overwrite -dict $dictDir/createBafflesDict > $targetDir/log04.createBaffles
    rm -r master/0
    # ここから
    cp -r $orgDir master_curve
    cp -r master/constant/polyMesh master_curve/constant/
    moveDynamicMesh -case master_curve > $targetDir/log045.moveDynamicMesh
    cp master_curve/1/polyMesh/points master/constant/polyMesh/
    # ここまで
    mergeMeshes master out -overwrite > $targetDir/log05.mergeMeshes
    stitchMesh -case master -overwrite wall_minx wall_maxx > $targetDir/log06.stitchMesh
    createPatch -case master -overwrite -dict $dictDir/createPatchDict > $targetDir/log07.createPatch
    rm -r master/0
popd

# 上羽根
target=wing_top # ここ

targetDir=$workDir/$target
mkdir -p $targetDir
cp -r $blockMeshDir/btm_shaft $targetDir/ # ここ！
cp -r $blockMeshDir/top_shaft $targetDir/
cp -r $blockMeshDir/out       $targetDir/

pushd $targetDir
    cp -r btm_shaft master
    mergeMeshes master top_shaft -overwrite > $targetDir/log01.mergeMeshes
    stitchMesh -case master -overwrite wall_minz_out wall_maxz_out > $targetDir/log02.stitchMesh
    topoSet -case master -dict $dictDir/topoSetDict > $targetDir/log03.topoSet
    createBaffles -case master -overwrite -dict $dictDir/createBafflesDict > $targetDir/log04.createBaffles
    rm -r master/0
    # ここから
    cp -r $orgDir master_curve
    cp -r master/constant/polyMesh master_curve/constant/
    moveDynamicMesh -case master_curve > $targetDir/log045.moveDynamicMesh
    cp master_curve/1/polyMesh/points master/constant/polyMesh/
    # ここまで
    mergeMeshes master out -overwrite > $targetDir/log05.mergeMeshes
    stitchMesh -case master -overwrite wall_minx wall_maxx > $targetDir/log06.stitchMesh
    createPatch -case master -overwrite -dict $dictDir/createPatchDict > $targetDir/log07.createPatch
    rm -r master/0
popd

# 羽根もシャフトもない場所
target=mid_bulk

targetDir=$workDir/$target
mkdir -p $targetDir
cp -r $blockMeshDir/mid_bulk  $targetDir/
cp -r $blockMeshDir/out       $targetDir/

pushd $targetDir
    cp -r mid_bulk master
    mergeMeshes master out -overwrite > $targetDir/log01.mergeMeshes
    stitchMesh -case master -overwrite wall_minx wall_maxx > $targetDir/log02.stitchMesh
    createPatch -case master -overwrite -dict $dictDir/createPatchDict > $targetDir/log03.createPatch
    rm -r master/0
popd

# 羽根はないけどシャフトはある場所
target=mid_shaft

targetDir=$workDir/$target
mkdir -p $targetDir
cp -r $blockMeshDir/mid_shaft $targetDir/
cp -r $blockMeshDir/out       $targetDir/

pushd $targetDir
    cp -r mid_shaft master
    mergeMeshes master out -overwrite > $targetDir/log01.mergeMeshes
    stitchMesh -case master -overwrite wall_minx wall_maxx > $targetDir/log02.stitchMesh
    createPatch -case master -overwrite -dict $dictDir/createPatchDict > $targetDir/log03.createPatch
    rm -r master/0
popd

for target in wing_btm wing_top mid_bulk mid_shaft
do
    cp -r $workDir/$target/master $resultDir/$target
done
