#!/bin/bash
cd ${0%/*} || exit 1 # 他の場所からこのスクリプトを実行したときのためのもの

partsDir=$PWD/../Ex6/results
resultDir=$PWD/results
workDir=$PWD/work
dictDir=$PWD/dicts

rm -r $workDir/* $resultDir/* # ※1
cd $workDir

# 00 一番下の部分　5mm up
cp -r $partsDir/mid_bulk master
transformPoints -case master -translate '(0.0 0.0 5.0e-3)' || exit 1

sed -i -e "s/minz/mindz/g"        master/constant/polyMesh/boundary
sed -i -e "s/maxz/maxdz/g"        master/constant/polyMesh/boundary

# 01 下の羽根 15mm up、シャフトの名前変更
cp -r $partsDir/wing_btm target1_wing_btm
transformPoints -case target1_wing_btm -translate '(0.0 0.0 15.0e-3)' || exit 1
sed -i -e "s/shaft/shaft_rotor/g" target1_wing_btm/constant/polyMesh/boundary # ※1
sed -i -e "s/minz/minuz/g"        target1_wing_btm/constant/polyMesh/boundary
sed -i -e "s/maxz/maxuz/g"        target1_wing_btm/constant/polyMesh/boundary

mergeMeshes -overwrite master target1_wing_btm || exit 1
stitchMesh -case master -overwrite wall_minuz wall_maxdz || exit 1
createPatch -case master -overwrite -dict $dictDir/createPatchDict || exit 1
rm -r master/0
sed -i -e "s/maxuz/maxdz/g"       master/constant/polyMesh/boundary

# 02 羽根と羽根の間 25mm up
cp -r $partsDir/mid_shaft target2_mid_shaft
transformPoints -case target2_mid_shaft -translate '(0.0 0.0 25.0e-3)' || exit 1
sed -i -e "s/minz/minuz/g" target2_mid_shaft/constant/polyMesh/boundary
sed -i -e "s/maxz/maxuz/g" target2_mid_shaft/constant/polyMesh/boundary

mergeMeshes -overwrite master target2_mid_shaft || exit 1
stitchMesh -case master -overwrite wall_minuz wall_maxdz || exit 1
createPatch -case master -overwrite -dict $dictDir/createPatchDict || exit 1
rm -r master/0
sed -i -e "s/maxuz/maxdz/g"       master/constant/polyMesh/boundary

# 03 上の羽根 35mm up、シャフトの名前変更
cp -r $partsDir/wing_top target3_wing_top
transformPoints -case target3_wing_top -translate '(0.0 0.0 35.0e-3)' || exit 1
sed -i -e "s/shaft/shaft_rotor/g" target3_wing_top/constant/polyMesh/boundary
sed -i -e "s/minz/minuz/g"        target3_wing_top/constant/polyMesh/boundary
sed -i -e "s/maxz/maxuz/g"        target3_wing_top/constant/polyMesh/boundary

mergeMeshes -overwrite master target3_wing_top || exit 1
stitchMesh -case master -overwrite wall_minuz wall_maxdz || exit 1
createPatch -case master -overwrite -dict $dictDir/createPatchDict || exit 1
rm -r master/0
sed -i -e "s/maxuz/maxdz/g"       master/constant/polyMesh/boundary

for z in 4 5 6 7 8 9 10
do
    targetDir=target${z}_mid_shaft
    cp -r $partsDir/mid_shaft $targetDir
    transformPoints -case $targetDir -translate "(0.0 0.0 ${z}5.0e-3)" || exit 1
    sed -i -e "s/minz/minuz/g" $targetDir/constant/polyMesh/boundary
    sed -i -e "s/maxz/maxuz/g" $targetDir/constant/polyMesh/boundary

    mergeMeshes -overwrite master $targetDir || exit 1
    stitchMesh -case master -overwrite wall_minuz wall_maxdz || exit 1
    createPatch -case master -overwrite -dict $dictDir/createPatchDict || exit 1
    rm -r master/0
    sed -i -e "s/maxuz/maxdz/g"       master/constant/polyMesh/boundary
done

cp -r master target11_rotation
sed -i -e "s/miny/minby/g"            master/constant/polyMesh/boundary
sed -i -e "s/maxy/maxby/g"            master/constant/polyMesh/boundary
sed -i -e "s/miny/minfy/g" target11_rotation/constant/polyMesh/boundary
sed -i -e "s/maxy/maxfy/g" target11_rotation/constant/polyMesh/boundary

for deg in 1 2 3 4 5
do
    transformPoints -case target11_rotation -rotate-angle '((0 0 1) 60)' || exit 1
    sed -i -e "s/maxfy/maxby/g" master/constant/polyMesh/boundary

    mergeMeshes -overwrite master target11_rotation || exit 1
    stitchMesh -case master -perfect -overwrite wall_minfy wall_maxby || exit 1
    createPatch -case master -overwrite -dict $dictDir/createPatchDict || exit 1
    rm -r master/0
done

stitchMesh -case master -perfect -overwrite wall_minby wall_maxfy || exit 1
createPatch -case master -overwrite -dict $dictDir/createPatchDict || exit 1
rm -r master/0

cp -r master $resultDir/allMesh
